Blacklog
========

* Allow multidimensional variables
* Create a units module (parse, validation, algebraic composition, etc)
* Python code compiler
* Detect dependencies between variables


Beta development
================


Releases
========

Version 0.1.0
-------------

* First release with bare bones functionality